pm4py.statistics.traces.generic.common package
==============================================

Submodules
----------

pm4py.statistics.traces.generic.common.case\_duration module
------------------------------------------------------------

.. automodule:: pm4py.statistics.traces.generic.common.case_duration
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.traces.generic.common
   :members:
   :undoc-members:
   :show-inheritance:
